<?php

$LANG = array(

'L_MENU'										=> 'Menú',
'L_UNKNOWN_ERROR'								=> 'Error desconocido',
'L_CONFIRM_DELETE'								=> '¿Desea confirmar la eliminación?',
'L_SAVE_FILE'									=> 'Guardar el archivo',
'L_SAVE_FILE_SUCCESSFULLY'						=> 'Archivo guardado correctamente',
'L_SAVE_FILE_ERROR'								=> 'Error al guardar el archivo',
'L_REPLY'										=> 'Contestación',
'L_REPLY_TO'									=> 'Contestación',
'L_CANCEL'										=> 'Cancelar',
'L_DELETE'										=> 'Eliminar',
'L_DELETE_FILE' 				    			=> 'Eliminar archivo',
'L_DELETE_FOLDER'				   				=> 'Eliminar carpeta',
'L_THUMBNAIL'									=> 'Miniatura (opcional)',
'L_THUMBNAIL_SELECTION'							=> 'Seleccionar Imagen',
'L_THUMBNAIL_TITLE'								=> 'Título de imagen (opcional)',
'L_THUMBNAIL_ALT'								=> 'El texto alternativo de la imagen (opcional)',
'L_ERR_INVALID_DATE_CREATION'					=> 'Fecha de creación no válida',
'L_ERR_INVALID_DATE_UPDATE'						=> 'Fecha no válida actualiza',

# class.plx.admin.php

'L_SAVE_SUCCESSFUL'								=> 'Se guradaron los datos correctamente',
'L_SAVE_ERR'									=> 'Error al guardar los datos',
'L_NO_ENTRY'									=> 'Acceso denegado',
'L_ERR_USER_EMPTY'								=> 'Introduzca un nombre de usuario',
'L_ERR_PASSWORD_EMPTY'							=> 'Introduzca una contraseña',
'L_ERR_PASSWORD_EMPTY_CONFIRMATION'				=> 'Contraseña incorrecta o vacía',
'L_ERR_INVALID_EMAIL'							=> 'Dirección de correo incorrecta',
'L_ERR_INVALID_SITE'							=> 'URL de sitio incorrecta',
'L_ERR_INVALID_ARTICLE_IDENT'					=> '¡Identificador de artículo incorrecto!',
'L_DEFAULT_NEW_CATEGORY_URL'					=> 'nueva-categoria',
'L_DEFAULT_NEW_STATIC_URL'						=> 'nueva-pagina',
'L_DEFAULT_NEW_ARTICLE_URL'						=> 'nuevo-articulo',
'L_ARTICLE_SAVE_SUCCESSFUL'						=> 'Artículo creado correctamente',
'L_ARTICLE_MODIFY_SUCCESSFUL'					=> 'Artículo actualizado correctamente',
'L_ARTICLE_DELETE_SUCCESSFUL'					=> 'Artículo eliminado correctamente',
'L_ARTICLE_SAVE_ERR'							=> 'Error al guardar el artículo',
'L_ARTICLE_DELETE_ERR'							=> 'Error al eliminar el artículo',
'L_ERR_UNKNOWN_COMMENT'							=> 'El comentario buscado no existe',
'L_COMMENT_SAVE_SUCCESSFUL'						=> 'Comentario guardado correctamente',
'L_COMMENT_UPDATE_ERR'							=> 'Error al actualizar el comentario',
'L_COMMENT_DELETE_SUCCESSFUL'					=> 'Comentario eliminado correctamente',
'L_COMMENT_DELETE_ERR'							=> 'Error al eliminar el comentario',
'L_COMMENT_VALIDATE_SUCCESSFUL'					=> 'Comentario aprobado correctamente',
'L_COMMENT_VALIDATE_ERR'						=> 'Error al aprobar el comentario',
'L_COMMENT_MODERATE_SUCCESSFUL'					=> 'Comentario moderado correctamente',
'L_COMMENT_MODERATE_ERR'						=> 'Error al moderar el comentario',
'L_ERR_URL_ALREADY_EXISTS'						=> 'URL ya utilizada. Cambie el valor del campo «URL»',

# class.plx.media.php

'L_PLXMEDIAS_MEDIAS_FOLDER_ERR'					=> 'No se pudo crear la carpeta de medios para el usuario',
'L_PLXMEDIAS_ROOT'								=> 'raíz',
'L_PLXMEDIAS_DELETE_FILES_SUCCESSFUL'			=> 'Archivos eliminados correctamente',
'L_PLXMEDIAS_DELETE_FILES_ERR'					=> 'Error al eliminar un archivo',
'L_PLXMEDIAS_DELETE_FILE_SUCCESSFUL'			=> 'Archivo eliminado correctamente',
'L_PLXMEDIAS_DELETE_FILE_ERR'					=> 'Error al eliminar el archivo',
'L_PLXMEDIAS_DEL_FOLDER_ERR'					=> 'Error al eliminar la carpeta',
'L_PLXMEDIAS_DEL_FOLDER_SUCCESSFUL'				=> 'Carpeta eliminada correctamente',
'L_PLXMEDIAS_NEW_FOLDER_ERR'					=> 'No se pudo crear la carpeta',
'L_PLXMEDIAS_NEW_FOLDER_SUCCESSFUL'				=> 'Carpeta creada correctamente',
'L_PLXMEDIAS_NEW_FOLDER_EXISTS'					=> 'Esta carpeta ya existe',
'L_PLXMEDIAS_WRONG_FILESIZE'					=> 'El tamaño de un archivo es superior a:',
'L_PLXMEDIAS_WRONG_FILEFORMAT'					=> 'El tipo de archivo no está permitido',
'L_PLXMEDIAS_UPLOAD_ERR'						=> 'Error al subir un archivo',
'L_PLXMEDIAS_UPLOAD_SUCCESSFUL'					=> 'Archivo subido correctamente',
'L_PLXMEDIAS_UPLOADS_ERR'						=> 'Error al subir archivos',
'L_PLXMEDIAS_UPLOADS_SUCCESSFUL'				=> 'Archivos subidos correctamente',
'L_PLXMEDIAS_MOVE_FILES_SUCCESSFUL'				=> 'Archivos movidos correctamente',
'L_PLXMEDIAS_MOVE_FILE_SUCCESSFUL'				=> 'Archivo movido correctamente',
'L_PLXMEDIAS_MOVE_FILES_ERR'					=> 'Error al mover los archivos',
'L_PLXMEDIAS_MOVE_FILE_ERR'						=> 'Error al mover el archivo',
'L_PLXMEDIAS_MOVE_FOLDER'						=> 'Mover',
'L_PLXMEDIAS_RECREATE_THUMB_ERR'				=> 'Error al crear la miniatura',
'L_PLXMEDIAS_RECREATE_THUMBS_ERR'				=> 'Error al crear las miniaturas',
'L_PLXMEDIAS_RECREATE_THUMB_SUCCESSFUL'			=> 'Miniatura creada correctamente',
'L_PLXMEDIAS_RECREATE_THUMBS_SUCCESSFUL'		=> 'Miniaturas creadas correctamente',

# article.php

'L_DEFAULT_NEW_ARTICLE_TITLE'					=> 'Nuevo artículo',
'L_ERR_INVALID_PUBLISHING_DATE'					=> 'Fecha de publicación incorrecta.',
'L_ERR_UNKNOWN_ARTICLE'							=> 'El artículo solicitado no existe.',
'L_ERR_FORBIDDEN_ARTICLE'						=> 'No tiene los permisos necesarios para acceder a este artículo ',
'L_BACK_TO_ARTICLES'							=> 'Volver a la lista de artículos',
'L_ARTICLE_EDITING'								=> 'Modificar un artículo',
'L_ARTICLE_TITLE'								=> 'Título',
'L_ARTICLE_LIST_AUTHORS'						=> 'Autor',
'L_HEADLINE_FIELD'								=> 'Subtítulo (opcional)',
'L_CONTENT_FIELD'								=> 'Contenido',
'L_LINK_FIELD'									=> 'Enlace al artículo',
'L_LINK_ACCESS'									=> 'Ir al artículo',
'L_LINK_VIEW'									=> 'ver',
'L_ARTICLE_STATUS'								=> 'Estado',
'L_DRAFT'										=> 'Borrador',
'L_PUBLISHED'									=> 'Publicado',
'L_AWAITING'									=> 'En espera de validación',
'L_ARTICLE_DATE'								=> 'Fecha de publicación',
'L_NOW'											=> 'ahora',
'L_ARTICLE_CATEGORIES'							=> 'Categorías',
'L_CATEGORY_HOME_PAGE'							=> 'Página de inicio',
'L_NEW_CATEGORY'								=> 'Nueva categoría', # duplicated in categories.php section
'L_ARTICLE_TAGS_FIELD'							=> 'Etiquetas',
'L_ARTICLE_TAGS_FIELD_TITLE'					=> 'Separe las etiquetas con comas',
'L_ARTICLE_TOGGLER_TITLE'						=> 'Lista de etiquetas',
'L_NO_TAG'										=> 'Ninguna etiqueta',
'L_ALLOW_COMMENTS'								=> 'Permitir comentarios',
'L_ARTICLE_URL_FIELD'							=> 'URL',
'L_ARTICLE_URL_FIELD_TITLE'						=> 'La URL se llena automáticamente durante la creación',
'L_ARTICLE_TEMPLATE_FIELD'						=> 'Plantilla',
'L_ARTICLE_MANAGE_COMMENTS'						=> 'Moderar los comentarios',
'L_ARTICLE_MANAGE_COMMENTS_TITLE'				=> 'Moderar los comentarios de este artículo',
'L_ARTICLE_NEW_COMMENT'							=> 'Escribir un comentario',
'L_ARTICLE_NEW_COMMENT_TITLE'					=> 'Escribir un comentario sobre este artículo',
'L_ARTICLE_DELETE_CONFIRM'						=> '¿Eliminar este artículo?',
'L_ARTICLE_PREVIEW_BUTTON'						=> 'Previsualización',
'L_ARTICLE_DRAFT_BUTTON'						=> 'Guardar borrador',
'L_ARTICLE_PUBLISHING_BUTTON'					=> 'Publicar',
'L_ARTICLE_MODERATE_BUTTON'						=> 'Agregar a cola de validación',
'L_ARTICLE_OFFLINE_BUTTON'						=> 'Poner invisible',
'L_ARTICLE_UPDATE_BUTTON'						=> 'Guardar',
'L_CATEGORY_ADD_BUTTON'							=> 'Agregar',
'L_ARTICLE_META_DESCRIPTION'					=> 'Contenido de la metaetiqueta de descripción («description», opcional)',
'L_ARTICLE_META_KEYWORDS'						=> 'Contenido de la metaetiqueta de palabras clave («keywords», opcional)',
'L_ARTICLE_TITLE_HTMLTAG'						=> 'Contenido de la etiqueta de título («title», opcional)',
'L_ARTICLE_CHAPO_HIDE'							=> 'ocultar',
'L_ARTICLE_CHAPO_DISPLAY'						=> 'mostrar',
'L_ARTICLE'										=> 'artículo',
'L_ARTICLE_ID'									=> 'Identificador',

# auth.php

'L_AUTH_PAGE_TITLE'								=> 'Página de autenticación',
'L_LOGOUT_SUCCESSFUL'							=> 'Sesión finalizada correctamente correctamente',
'L_LOGIN_PAGE'									=> 'Iniciar sesión en la zona de administración',
'L_AUTH_LOGIN_FIELD'							=> 'Nombre de usuario',
'L_AUTH_PASSWORD_FIELD'							=> 'Contraseña',
'L_SUBMIT_BUTTON'								=> 'Enviar',
'L_ERR_WRONG_PASSWORD'							=> 'Nombre de usuario o contraseña incorrectos',
'L_POWERED_BY'									=> 'Generado con <a href="http://www.pluxml.org">PluXml</a>',

#

'L_SORT_ASCENDING_DATE'							=> 'más antiguo a más reciente',
'L_SORT_DESCENDING_DATE'						=> 'más reciente a más antiguo',
'L_SORT_ALPHABETICAL'							=> 'alfabético',
'L_YES'											=> 'Si',
'L_NO'											=> 'No',
'L_OK'											=> 'OK',
'L_NONE1'										=> 'ninguno',
'L_NONE2'										=> 'ninguna',

# categories.php

'L_CAT_TITLE'									=> 'Gestor de categorías',
'L_CAT_LIST_ID'									=> 'Identificador',
'L_CAT_LIST_ACTIVE'								=> 'Activa',
'L_CAT_LIST_NAME'								=> 'Nombre de la categoría',
'L_CAT_LIST_URL'								=> 'URL',
'L_CAT_LIST_SORT'								=> 'Ordenar artículos',
'L_CAT_LIST_BYPAGE'								=> 'Artículo/página',
'L_CAT_LIST_ORDER'								=> 'Orden',
'L_CAT_LIST_MENU'								=> 'Menú',
'L_CATEGORY'									=> 'Categoría',
'L_DISPLAY'										=> 'Mostrar',
'L_HIDE'										=> 'Esconder',
'L_OPTIONS'										=> 'Opciones',
'L_NEW_CATEGORY'								=> 'Nueva categoría',
'L_FOR_SELECTION'								=> 'Elementos seleccionados...',
'L_CAT_APPLY_BUTTON'							=> 'Modificar la lista de categorías',
'L_CAT_UNKNOWN'									=> 'Categoría desconocida',

# categorie.php

'L_EDITCAT_PAGE_TITLE'							=> 'Editar opciones de categoría',
'L_EDITCAT_DESCRIPTION'							=> 'Descripción',
'L_EDITCAT_DISPLAY_HOMEPAGE'					=> 'Mostrar artículos en la página principal',
'L_EDITCAT_TEMPLATE'							=> 'Plantilla',
'L_EDITCAT_BACK_TO_PAGE'						=> 'Volver a la lista de categorías',
'L_EDITCAT_UPDATE'								=> 'Actualizar esta categoría',
'L_EDITCAT_TITLE_HTMLTAG'						=> 'Contenido de la etiqueta de título («title», opcional)',
'L_EDITCAT_META_DESCRIPTION'					=> 'Contenido de la metaetiqueta de descripción («description», opcional) ',
'L_EDITCAT_META_KEYWORDS'						=> 'Contenido de la metaetiqueta de palabras clave («keywords», opcional)',

# commentaire.php

'L_COMMENT_ORPHAN'								=> 'sin artículo',
'L_COMMENT_ORPHAN_STATUS'						=> 'invisible (sugerimos elimiar este comentario)',
'L_COMMENT_ARTICLE_LINKED'						=> 'Artículo',
'L_COMMENT_ARTICLE_LINKED_TITLE'				=> 'Artículo asociado a este comentario',
'L_COMMENT_OFFLINE'								=> 'desconectado',
'L_COMMENT_ONLINE'								=> 'conectado',
'L_COMMENT_ONLINE_TITLE'						=> 'Lista de comentarios publicados',
'L_BACK_TO_ARTICLE_COMMENTS'					=> 'Volver a la lista de comentarios de este artículo',
'L_BACK_TO_COMMENTS'							=> 'Volver a la lista de comentarios',
'L_COMMENT_EDITING'								=> 'Modificar un comentario',
'L_COMMENT_AUTHOR_FIELD'						=> 'Autor',
'L_COMMENT_TYPE_FIELD'							=> 'Tipo de comentario',
'L_COMMENT_DATE_FIELD'							=> 'Fecha y hora de publicación',
'L_COMMENT_IP_FIELD'							=> 'IP',
'L_COMMENT_SITE_FIELD'							=> 'Sitio web',
'L_COMMENT_EMAIL_FIELD'							=> 'Dirección de correo',
'L_COMMENT_STATUS_FIELD'						=> 'Estado',
'L_COMMENT_LINKED_ARTICLE_FIELD'				=> 'Artículo asociado',
'L_COMMENT_ARTICLE_FIELD'						=> 'Comentarios',
'L_COMMENT_DELETE_CONFIRM'						=> '¿Desea eliminar este comentario?',
'L_COMMENT_PUBLISH_BUTTON'						=> 'Aprobar la publicación',
'L_COMMENT_OFFLINE_BUTTON'						=> 'Cambiar a invisible',
'L_COMMENT_ANSWER_BUTTON'						=> 'Responder a este comentario',
'L_COMMENT_UPDATE_BUTTON'						=> 'Actualizar',
'L_COMMENT_WRITTEN_BY'							=> 'Escrito por',
'L_ERR_CATEGORY_ALREADY_EXISTS'					=> 'Ya existe una categoría con ese nombre',

# sous_navigation/commentaires.php

'L_COMMENT_NEW_COMMENT_TITLE'					=> 'Escribir un nuevo comentario para este artículo',
'L_COMMENT_NEW_COMMENT'							=> 'Escribir un nuevo comentario',

# commentaire_new.php

'L_ERR_ANSWER_UNKNOWN_COMMENT'					=> '¡El comentario al que está intentando responder no existe!',
'L_ERR_ANSWER_OFFLINE_COMMENT'					=> '¡Es imposible responder a un comentario invisible!',
'L_ERR_COMMENT_UNKNOWN_ARTICLE'					=> '¡Es imposible comentar en un artículo que no existe!',
'L_ERR_CREATING_COMMENT'						=> 'Error grave durante la creación del comentario',
'L_CREATING_COMMENT_SUCCESSFUL'					=> 'Comentario creado correctamente',
'L_CREATE_NEW_COMMENT'							=> 'Escribir un comentario',
'L_COMMENT_SAVE_BUTTON'							=> 'Guardar',
'L_ARTICLE_COMMENTS_LIST'						=> 'Comentarios de este artículo (del más reciente al más antiguo)',
'L_COMMENT_ANSWER_TITLE'						=> 'Responder a este comentario',
'L_COMMENT_ANSWER'								=> 'Responder',

# comments.php

'L_COMMENTS_ARTICLE_SCOPE'						=> 'Artículo',
'L_COMMENTS_GLOBAL_SCOPE'						=> 'todo el sitio',
'L_COMMENTS_LIST_DATE'							=> 'Fecha',
'L_COMMENTS_LIST_AUTHOR'						=> 'Autor',
'L_COMMENTS_LIST_MESSAGE'						=> 'Mensaje',
'L_COMMENTS_LIST_ACTION'						=> 'Acción',
'L_COMMENT_EDIT'								=> 'Editar',
'L_COMMENT_EDIT_TITLE'							=> 'Editar este comentario',
'L_COMMENT_DELETE'								=> 'Eliminar',
'L_COMMENT_OFFLINE_FEEDS_TITLE'					=> 'Sindicación RSS de los comentarios invisibles',
'L_COMMENT_OFFLINE_FEEDS'						=> 'Comentarios invisibles',
'L_COMMENT_ONLINE_FEEDS_TITLE'					=> 'Sindicación RSS de los comentarios visibles',
'L_COMMENT_ONLINE_FEEDS'						=> 'Comentarios visibles',
'L_COMMENTS_PRIVATE_FEEDS'						=> 'Sindicaciones RSS privadas',
'L_COMMENTS_ONLINE_LIST'						=> 'Lista de revisiones publicadas',
'L_COMMENTS_OFFLINE_LIST'						=> 'Comentarios esperando moderación',
'L_COMMENTS_ALL_LIST'							=> 'Lista de comentarios',
'L_COMMENT_SET_ONLINE'							=> 'Configurar como visible',
'L_COMMENT_SET_OFFLINE'							=> 'Configurar como invisible',

# index.php

'L_ARTICLES_SEARCH_BUTTON'						=> 'Búsqueda',
'L_ARTICLES_ALL_CATEGORIES'						=> 'Todas las categorías...',
'L_ALL'											=> 'Todos',
'L_ALL_PUBLISHED'								=> 'Publicados',
'L_ALL_DRAFTS'									=> 'Borradores',
'L_ALL_AWAITING_MODERATION'						=> 'En espera de validación',
'L_ARTICLES_FILTER_BUTTON'						=> 'Filtrar',
'L_CATEGORIES_TABLE'							=> 'Categorías',
'L_SPECIFIC_CATEGORIES_TABLE'					=> 'Categorías específicas',
'L_ALL_ARTICLES_CATEGORIES_TABLE'				=> 'Todos los artículos',
'L_ARTICLES_LIST'								=> 'Lista de artículos',
'L_ARTICLE_LIST_DATE'							=> 'Fecha',
'L_ARTICLE_LIST_TITLE'							=> 'Título',
'L_ARTICLE_LIST_CATEGORIES'						=> 'Categoría',
'L_ARTICLE_LIST_NBCOMS'							=> 'Cant. de comentarios',
'L_ARTICLE_LIST_AUTHOR'							=> 'Autor',
'L_ARTICLE_LIST_ACTION'							=> 'Acción',
'L_CATEGORY_HOME'								=> 'Inicio',
'L_CATEGORY_DRAFT'								=> 'Borrador',
'L_ARTICLE_VIEW'								=> 'Visualizar',
'L_ARTICLE_VIEW_TITLE'							=> 'Visualizar este artílo en el sitio',
'L_ARTICLE_EDIT'								=> 'Editar',
'L_ARTICLE_EDIT_TITLE'							=> 'Editar este artículo',
'L_NEW_COMMENTS_TITLE'							=> 'Comentarios en espera de moderación',
'L_VALIDATED_COMMENTS_TITLE'					=> 'Comentarios publicados',
'L_NO_ARTICLE'									=> 'No existe este artículo',

# medias.php

'L_MEDIAS_FILENAME'								=> 'Nombre del archivo',
'L_MEDIAS_TITLE'								=> 'Gestión de medios',
'L_MEDIAS_DIRECTORY'							=> 'Localización',
'L_MEDIAS_BACK'									=> 'Volver',
'L_MEDIAS_MAX_UPOLAD_FILE'						=> 'Tamaño máximo de archivo',
'L_MEDIAS_SUBMIT_FILE'							=> 'Enviar',
'L_MEDIAS_IMAGES'								=> 'Imágenes',
'L_MEDIAS_DOCUMENTS'							=> 'Documentos',
'L_MEDIAS_ADD_FILE'								=> 'Agregar archivo',
'L_MEDIAS_DELETE_FOLDER'						=> 'Eliminar la carpeta',
'L_MEDIAS_DELETE_FOLDER_CONFIRM'				=> '¿Desea eliminar la carpeta %s y su contenido?',
'L_MEDIAS_FOLDER'								=> 'Archivo',
'L_MEDIAS_NEW_FOLDER'							=> 'Nueva carpeta',
'L_MEDIAS_CREATE_FOLDER'						=> 'Crear una carpeta',
'L_MEDIAS_FILESIZE'								=> 'Tamaño',
'L_MEDIAS_DATE'									=> 'Fecha',
'L_MEDIAS_DIMENSIONS'							=> 'Dimensiones',
'L_MEDIAS_NO_FILE'								=> 'Sin archivos',
'L_MEDIAS_RESIZE'								=> 'Cambiar el tamaño de las imágenes',
'L_MEDIAS_RESIZE_NO'							=> 'Tamaño original',
'L_MEDIAS_THUMBS'								=> 'Crear miniaturas',
'L_MEDIAS_THUMBS_NONE'							=> 'Sin miniatura',
'L_MEDIAS_MODIFY'								=> 'Editar',
'L_MEDIAS_THUMB'								=> 'Miniatura',
'L_MEDIAS_EXTENSION'							=> 'Extensión',
'L_MEDIAS_ADD'									=> 'Agregar',
'L_MEDIAS_ALIGNMENT'							=> 'Alineación',
'L_MEDIAS_ALIGN_NONE'							=> 'Ninguna',
'L_MEDIAS_ALIGN_LEFT'							=> 'Izquierda',
'L_MEDIAS_ALIGN_CENTER'							=> 'Centro',
'L_MEDIAS_ALIGN_RIGHT'							=> 'Derecha',
'L_MEDIAS_RECREATE_THUMB'						=> 'Crear miniatura nuevamente',

# parametres_affichage.php

'L_CONFIG_VIEW_FIELD'							=> 'Opciones de visualización',
'L_CONFIG_VIEW_SKIN_SELECT'						=> 'Elegir tema',
'L_CONFIG_VIEW_FILES_EDIT_TITLE'				=> 'Editar archivos del tema',
'L_CONFIG_VIEW_FILES_EDIT'						=> 'Editar archivos del tema',
'L_CONFIG_VIEW_SORT'							=> 'Ordenar artículos',
'L_CONFIG_VIEW_BYPAGE'							=> 'Cantidad de artículos por página',
'L_CONFIG_VIEW_BYPAGE_ARCHIVES'					=> 'Cantidad de artículos por página en los archivos',
'L_CONFIG_VIEW_BYPAGE_ADMIN'					=> 'Cantidad de artículos por página en la página de administración',
'L_CONFIG_VIEW_SORT_COMS'						=> 'Ordenar comentarios',
'L_CONFIG_VIEW_BYPAGE_ADMIN_COMS'				=> 'Cantidad de comentarios por página en la página de administración',
'L_CONFIG_VIEW_IMAGES'							=> 'Tamaño de la imagen (largo x ancho)',
'L_CONFIG_VIEW_THUMBS'							=> 'Tamaño de las miniaturas (largo x ancho)',
'L_CONFIG_VIEW_HOMESTATIC'						=> 'Utilizar una página estática como página de inicio',
'L_CONFIG_VIEW_HOMESTATIC_ACTIVE'				=> 'Advertencia: esta página está desactivada',
'L_CONFIG_VIEW_PLUXML_RESSOURCES'				=> 'Descargar otros temas en <a href="http://ressources.pluxml.org">ressources.pluxml.org</a>.',
'L_CONFIG_VIEW_BYPAGE_FEEDS'					=> 'Cantidad de artículos en la sindicación RSS',
'L_CONFIG_VIEW_FEEDS_HEADLINE'					=> 'Sómo mostrar subtítulos en la sindicación RSS de los artículos',
'L_CONFIG_VIEW_FEEDS_HEADLINE_HELP'				=> 'En caso de que el subtítulo esté vacío, se mostrará el contenido',
'L_CONFIG_VIEW_FEEDS_FOOTER'					=> 'Texto al final de cada artículo en la sindicación RSS',
'L_CONFIG_VIEW_UPDATE'							=> 'Guardar opciones de visualización',
'L_CONFIG_VIEW_DISPLAY_EMPTY_CAT'				=> 'Mostrar categorías sin artículos',
'L_CONFIG_HOMETEMPLATE'							=> 'Plantilla de la página principal',

# parametres_avances.php

'L_CONFIG_ADVANCED_DESC'						=> 'Configuración avanzada',
'L_CONFIG_ADVANCED_URL_REWRITE'					=> 'Activar la reescritura de URLs',
'L_CONFIG_ADVANCED_URL_REWRITE_ALERT'			=> 'Advertencia: ya existe un archivo «.htaccess» en la raíz de su instalación de PluXml. Si activa la reescritura de URLs, se modificará este archivo',
'L_CONFIG_ADVANCED_GZIP'						=> 'Activar compresión GZIP',
'L_CONFIG_ADVANCED_GZIP_HELP'					=> 'Permite comprimir las páginas para ahorrar ancho de banda, pero puede aumentar la carga del procesador',
'L_CONFIG_ADVANCED_CAPCHA'						=> 'Activar protección nti-spam («CAPTCHA»)',
'L_CONFIG_ADVANCED_ADMIN_KEY'					=> 'Clave de administración (URLs privadas)',
'L_CONFIG_ADVANCED_KEY_HELP'					=> 'Deje este campo vacío para regenerar la clave',
'L_CONFIG_ADVANCED_USERFOLDERS'					=> 'Utilizar carpetas diferentes para medias en cada usuario',
'L_HELP_SLASH_END'								=> 'No olvide la barra al final',
'L_CONFIG_ADVANCED_MEDIAS_FOLDER'				=> 'Ubicación de la carpeta de medios',
'L_CONFIG_ADVANCED_ARTS_FOLDER'					=> 'Ubicación de la carpeta de artículos',
'L_CONFIG_ADVANCED_COMS_FOLDER'					=> 'Ubicación de la carpeta de comentarios',
'L_CONFIG_ADVANCED_STATS_FOLDER'				=> 'Ubicación de la carpeta de páginas éstaticas',
'L_CONFIG_ADVANCED_THEMES_FOLDER'				=> 'Ubicación de la carpeta de temas',
'L_CONFIG_ADVANCED_PLUGINS_FOLDER'				=> 'Ubicación de la carpeta de complementos',
'L_CONFIG_ADVANCED_CONFIG_FOLDER'				=> 'Ubicación de la carpeta de configuración',
'L_CONFIG_ADVANCED_UPDATE'						=> 'Guardar configuración avanzada',
'L_CONFIG_CUSTOM_CSSADMIN_PATH'					=> 'Ubicación y nombre del archivo CSS personalizado del área de administración (opcional)',

# parametres_base.php

'L_CONFIG_BASE_CONFIG_TITLE'					=> 'Configuración básica',
'L_CONFIG_BASE_SITE_TITLE'						=> 'Título del sitio',
'L_CONFIG_BASE_SITE_SLOGAN'						=> 'Subtítulo y descripción del sitio',
'L_CONFIG_BASE_URL_HELP'						=> 'No olvide la barra al final',
'L_CONFIG_BASE_DEFAULT_LANG'					=> 'Idioma predeterminado',
'L_CONFIG_BASE_TIMEZONE'						=> 'Huso horario',
'L_CONFIG_BASE_ALLOW_COMMENTS'					=> 'Permitir comentarios',
'L_CONFIG_BASE_MODERATE_COMMENTS'				=> 'Moderar los comentarios creados',
'L_CONFIG_BASE_MODERATE_ARTICLES'				=> 'Moderar los artículos para los perfiles «Redactor» y «Editor»',
'L_CONFIG_BASE_UPDATE'							=> 'Guardar la configuración básica',
'L_CONFIG_META_DESCRIPTION'						=> 'Contenido de la metaetiqueta de description («description», opcional)',
'L_CONFIG_META_KEYWORDS'						=> 'Contenido de la metaetiqueta de palabras clave («keywords», opcional)',

# parametres_edittpl.php

'L_CONFIG_EDITTPL_ERROR_NOTHEME'				=> '¡No existe el tema!',
'L_CONFIG_EDITTPL_TITLE'						=> 'Edición del tema',
'L_CONFIG_EDITTPL_SELECT_FILE'					=> 'Seleccione un archivo para editar:',
'L_CONFIG_EDITTPL_LOAD'							=> 'Cargar',

# parametres_infos.php

'L_CONFIG_INFOS_TITLE'							=> 'Información sobre PluXml',
'L_CONFIG_INFOS_DESCRIPTION'					=> 'Información sobre su instalación de PluXml, puede serle útil para diagnosticar problemas.',
'L_CONFIG_INFOS_NB_CATS'						=> 'Cantidad de categorías:',
'L_CONFIG_INFOS_NB_STATICS'						=> 'Cantidad de páginas estáticas:',
'L_CONFIG_INFOS_WRITER'							=> 'Cantidad de usuarios en sesión:',
'L_PLUXML_CHECK_VERSION'						=> 'Comprobación de la versión de PluXml en el sitio oficial PluXml.org',
'L_PLUXML_UPDATE_UNAVAILABLE'					=> 'Es imposible comprobar las actualizaciones disponibles si la función «allow_url_fopen» está desactivada en este sistema',
'L_PLUXML_UPDATE_ERR'							=> 'Falló la comprobación de actualizaciones por una razón desconocida',
'L_PLUXML_UPTODATE'								=> 'Está utilizando la última versión de PluXml',
'L_PLUXML_UPDATE_AVAILABLE'						=> '¡Existe una nueva versión de PluXml! Puede descargarla desde',

# parametres_users.php

'L_CONFIG_USERS_TITLE'							=> 'Gestión de usuarios',
'L_CONFIG_USER'									=> 'Usuario',
'L_CONFIG_USERS_ID'								=> 'Identificador de usuario',
'L_CONFIG_USERS_ACTIVE'							=> 'Activo',
'L_CONFIG_USERS_ACTION'							=> 'Acción',
'L_CONFIG_USERS_NEW'							=> 'Nuevo usuario',
'L_CONFIG_USERS_UPDATE'							=> 'Modificar la lista de usuarios',
'L_ERR_LOGIN_ALREADY_EXISTS'					=> 'Ya existe un usuario con ese identificador',
'L_ERR_USERNAME_ALREADY_EXISTS'					=> 'Ya existe un usuario con ese nombre',
'L_CONFIG_USERS_DELETE_CONFIRM'					=> '¿Desea eliminar los usuarios seleccionados?',

# parametre_plugins.php

'L_BACK_TO_PLUGINS'								=> 'Volver a la página de complementos',
'L_NO_PLUGIN'									=> 'Ningún complemento',
'L_PLUGIN_NO_CONFIG'							=> 'Complemento sin configuración',
'L_PLUGINS_CSS'									=> 'Código CSS',
'L_PLUGINS_CSS_TITLE'							=> 'Editar el código CSS del complemento',
'L_CONTENT_FIELD_FRONTEND'						=> 'Contenido del archivo de código CSS para el sitio web',
'L_CONTENT_FIELD_BACKEND'						=> 'Contenido del archivo de código CSS para el sitio de administración',

# parametres_plugins.php

'L_PLUGINS_TITLE'								=> 'Gestión de complementos',
'L_PLUGINS_VERSION'								=> 'Versión',
'L_PLUGINS_AUTHOR'								=> 'Autor',
'L_PLUGINS_ACTIVATE'							=> 'Activar',
'L_PLUGINS_DEACTIVATE'							=> 'Desactivar',
'L_PLUGINS_DELETE'								=> 'Eliminar',
'L_PLUGINS_DELETE_ERROR'						=> 'Error al eliminar el complemento',
'L_PLUGINS_DELETE_SUCCESSFUL'					=> 'Complemento eliminado correctamente',
'L_PLUGINS_CONFIG'								=> 'Configuración',
'L_PLUGINS_CONFIG_TITLE'						=> 'Configuración del complemento',
'L_PLUGINS_REQUIREMENTS'						=> 'Requerimientos',
'L_PLUGINS_REQUIREMENTS_HELP'					=> 'Complementos disponibles y activos necesarios para activar este complemento',
'L_PLUGINS_REQUIREMENTS_NONE'					=> 'Ninguno',
'L_PLUGINS_ALPHA_SORT'							=> 'Ordenar complementos alfabéticamente',
'L_PLUGINS_LOADING_SORT'						=> 'Orden de cargar',
'L_PLUGINS_ACTION'								=> 'Acción',
'L_PLUGINS_APPLY_BUTTON'						=> 'Modificar la lista de complementos',
'L_PLUGINS_ACTIVE_LIST'							=> 'Complementos activos',
'L_PLUGINS_INACTIVE_LIST'						=> 'Complementos desactivados',

# profil.php

'L_PROFIL_EDIT_TITLE'							=> 'Edición de perfiles',
'L_PROFIL'										=> 'Perfil',
'L_PROFIL_LOGIN'								=> 'Cuenta de usuario',
'L_PROFIL_USER'									=> 'Nombre de usuario',
'L_PROFIL_MAIL'									=> 'Dirección correo',
'L_PROFIL_ADMIN_LANG'							=> 'Idioma de administración',
'L_PROFIL_INFOS'								=> 'Información',
'L_PROFIL_UPDATE'								=> 'Guardar perfil',
'L_PROFIL_CHANGE_PASSWORD'						=> 'Cambiar contraseña',
'L_PROFIL_PASSWORD'								=> 'Contraseña',
'L_PROFIL_CONFIRM_PASSWORD'						=> 'Confirme la contraseña',
'L_PROFIL_UPDATE_PASSWORD'						=> 'Cambiar contraseña',

# statique.php

'L_STATIC_BACK_TO_PAGE'							=> 'Volver a la lista de páginas estáticas',
'L_STATIC_UNKNOWN_PAGE'							=> '¡No existe esta página estática!',
'L_STATIC_TITLE'								=> 'Editar código fuente de la página estática',
'L_STATIC_VIEW_PAGE'							=> 'Visualizar página',
'L_STATIC_ON_SITE'								=> 'en el sitio',
'L_STATIC_UPDATE'								=> 'Guardar esta página',
'L_STATIC_TITLE_HTMLTAG'						=> 'Contenido de la etiqueta de título («title», opcional)',
'L_STATIC_META_DESCRIPTION'						=> 'Contenido de la metaetiqueta de descripción («description», opcional)',
'L_STATIC_META_KEYWORDS'						=> 'Contenido de la metaetiqueta de palabras claves («keywords», opcional)',

# statiques.php

'L_STATICS_PAGE_TITLE'							=> 'Crear y editar páginas estáticas',
'L_STATICS_ID'									=> 'Identificador',
'L_STATICS_GROUP'								=> 'Grupo',
'L_STATICS_TITLE'								=> 'Título',
'L_STATICS_URL'									=> 'URL',
'L_STATICS_ACTIVE'								=> 'Activo',
'L_STATICS_ORDER'								=> 'Orden',
'L_STATICS_MENU'								=> 'Menú',
'L_STATICS_ACTION'								=> 'Acción',
'L_STATICS_TEMPLATE_FIELD'						=> 'Plantilla',
'L_STATICS_PAGE_HOME'							=> 'Establecer como página de inicio',
'L_STATICS_HOME_PAGE'							=> 'Página de inicio',
'L_PAGE'										=> 'Página',
'L_VIEW'										=> 'Visualizar',
'L_STATICS_SRC_TITLE'							=> 'Editar código fuente de esta página',
'L_STATICS_SRC'									=> 'Editar',
'L_STATICS_NEW_PAGE'							=> 'Nueva página',
'L_STATICS_UPDATE'								=> 'Modificar la lista de las páginas estáticas',
'L_ERR_STATIC_ALREADY_EXISTS'					=> 'Ya existe una página con ese título',

# top.php
'L_PROFIL_ADMIN'								=> 'Administrador',
'L_PROFIL_MANAGER'								=> 'Gestor',
'L_PROFIL_MODERATOR'							=> 'Moderador',
'L_PROFIL_EDITOR'								=> 'Editor',
'L_PROFIL_WRITER'								=> 'Redactor',
'L_ADMIN'										=> '- Administración',
'L_LOGIN'										=> 'Connectado como',
'L_ADMIN_LOGOUT'								=> 'Desconectar',
'L_ADMIN_LOGOUT_TITLE'							=> 'Finalizar sesión del administrador',
'L_BACK_TO_SITE'								=> 'Inicio',
'L_BACK_TO_SITE_TITLE'							=> 'Volver al inicio',
'L_BACK_TO_BLOG'								=> 'Blog',
'L_BACK_TO_BLOG_TITLE'							=> 'Volver al blog',
'L_MENU_ARTICLES'								=> 'Artículos',
'L_MENU_ARTICLES_TITLE'							=> 'Enumerar o editar artículos',
'L_MENU_NEW_ARTICLES'							=> 'Nuevo artículo',
'L_MENU_NEW_ARTICLES_TITLE'						=> 'Nuevo artículo',
'L_MENU_STATICS_TITLE'							=> 'Enumerar o editar páginas estáticas',
'L_MENU_STATICS'								=> 'Páginas estáticas',
'L_MENU_COMMENTS_TITLE'							=> 'Enumerar o editar comentarios',
'L_MENU_COMMENTS'								=> 'Comentarios',
'L_MENU_MEDIAS_TITLE'							=> 'Subir e insertar un medio',
'L_MENU_MEDIAS'									=> 'Medios',
'L_MENU_CATEGORIES_TITLE'						=> 'Crear, gestionar y editar categorías',
'L_MENU_CATEGORIES'								=> 'Categorías',
'L_MENU_CONFIG_TITLE'							=> 'Configurar PluXml',
'L_MENU_CONFIG'									=> 'Parámetros',
'L_MENU_PROFIL_TITLE'							=> 'Gestionar sus perfiles de usuario',
'L_MENU_PROFIL'									=> 'Perfil',
'L_WARNING_INSTALLATION_FILE'					=> 'Todavía existe el archivo «install.php» en la raíz de PluXml.<br />Por razones de seguridad, le sugerimos que lo elimine.',

# user.php
'L_USER_UNKNOWN'								=> 'Usuario desconocido',
'L_USER_LANG'									=> 'Idioma utilizado en la administración',
'L_USER_MAIL'									=> 'Dirección de correo',
'L_USER_INFOS'									=> 'Información',
'L_USER_UPDATE'									=> 'Actualizar este usuario',
'L_USER_PAGE_TITLE'								=> 'Editar opciones de usuario',
'L_USER_BACK_TO_PAGE'							=> 'Volver a la lista de usuarios',

#

'L_MENU_CONFIG_BASE_TITLE'						=> 'Editar configuración básica de PluXml',
'L_MENU_CONFIG_BASE'							=> 'Configuración básica',
'L_MENU_CONFIG_VIEW_TITLE'						=> 'Esitar sus opciones de visualización de PluXml',
'L_MENU_CONFIG_VIEW'							=> 'Opciones de visualización',
'L_MENU_CONFIG_USERS_TITLE'						=> 'Gestionar cuentas de usuario de PluXml',
'L_MENU_CONFIG_USERS'							=> 'Cuentas de usuario',
'L_MENU_CONFIG_ADVANCED_TITLE'					=> 'Editar configuración avanzada de PluXml',
'L_MENU_CONFIG_ADVANCED'						=> 'Configuración avanzada',
'L_MENU_CONFIG_INFOS_TITLE'						=> 'Información de PluXml',
'L_MENU_CONFIG_INFOS'							=> 'Información',
'L_MENU_CONFIG_PLUGINS_TITLE'					=> 'Gestionar complementos',
'L_MENU_CONFIG_PLUGINS'							=> 'Complementos',
'L_THEMES'										=> 'Temas',
'L_THEMES_TITLE'								=> 'La gestión de temas',
'L_HELP'										=> 'Ayuda',
'L_HELP_TITLE'									=> 'Consulte la ayuda',
'L_BACK_TO_THEMES'								=> 'Volver a la lista de temas',
);
?>